import os
import cv2
import time



def camera():
    cap = cv2.VideoCapture(0)
    while(1):
        ret, frame = cap.read()
        cv2.imshow("capture", frame)
        if cv2.waitKey(1) & 0xFF == ord('q'):
            now = time.localtime()
            filename = str(now.tm_year) + str(now.tm_mon) + str(now.tm_mday) + str(now.tm_hour) + str(now.tm_min) + str(now.tm_sec) + '.jpg'
            cv2.imwrite(filename, frame)
            break
    cap.release()
    cv2.destroyAllWindows()
    return filename




def main():
    res = camera()
    print(res)




if __name__ == '__main__':
    main()



from distutils.core import setup
setup(
  name = 'ybc_camera',
  packages = ['ybc_camera'],
  version = '1.0.0',
  description = 'ybc camera',
  long_description='ybc camera',
  author = 'KingHS',
  author_email = '382771946@qq.com',
  keywords = ['pip3', 'python3','python','camera'],
  license='MIT',
  install_requires=['opencv-python']
)
